# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.3.0] - 2024-04-08

### Added

- Check `requires` and `tool_requires` function calls in in `conanfile.py`
- Python 3.12 support

### Fixed

- Ignore line comments in conanfile.txt

## [0.2.0] - 2022-02-18

### Added

- Add --upgrade / -u option to update conanfile
- Conan v2 compatibility and tests
- Build wheel for PyPI
- Handle revisions

### Changed

- Get requirements directly from conanfile.py/conanfile.txt instead running conan info

## [0.1.0] - 2021-12-16

Initial public release

[Unreleased]: https://github.com/lukasberbuer/conan-check-updates/compare/v0.3.0...HEAD
[0.3.0]: https://github.com/lukasberbuer/conan-check-updates/compare/v0.2.0...v0.3.0
[0.2.0]: https://github.com/lukasberbuer/conan-check-updates/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/lukasberbuer/conan-check-updates/releases/tag/v0.1.0
